@@ -1,6 +1,6 @@
 package BankAccount::Validator::UK;
 
-$BankAccount::Validator::UK::VERSION   = '0.30';
+$BankAccount::Validator::UK::VERSION   = '0.31';
 $BankAccount::Validator::UK::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ BankAccount::Validator::UK - Interface to validate UK bank account.
 
 =head1 VERSION
 
-Version 0.30
+Version 0.31
 
 =cut
 
@@ -36,7 +36,7 @@ has sort_code  => (is => 'ro', default => sub { BankAccount::Validator::UK::Rule
 The module uses the algorithm provided by VOCALINK to validate the bank sort code
 and account number.  It is  done by modulus  checking  method as specified in the
 document which is available on their website L<VOCALINK|https://www.vocalink.com/customer-support/modulus-checking>
-It currently supports the L<document|https://www.vocalink.com/media/2467/vocalink-validating-account-numbers-v430.pdf> v4.30 dated 3rd July 2017.
+It currently supports the document L<v4.40|https://www.vocalink.com/media/2717/vocalink-validating-account-numbers-v440.pdf> dated 21st August 2017.
 
 Institutions covered by this document are below:
 
